Installation — gntplib 0.5 documentation

# Installation

Simply use pip:

    $ pip install gntplib

There are the following optional prerequisites.

- `pycrypto` - to use `gntplib.ciphers` module for message encryption

- `tornado` - to use `gntplib.async` module for asynchronous processing

Let’s send a simple notification to test installation. Use `gntplib.publish()`:

    >>> import gntplib
    >>> gntplib.publish('App', 'Event', 'Hello, Growl!')